==> ajaxplorer-4.2.3.tbz: www/ajaxplorer/plugins/action.updater/i18n/conf/en.php <==
<?php
/*
* Copyright 2007-2011 Charles du Jeu <contact (at) cdujeu.me>
* This file is part of AjaXplorer.
*
* AjaXplorer is free software: you can redistribute it and/or modify
* it under the terms of the GNU Affero General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* AjaXplorer is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU Affero General Public License for more details.
*
* You should have received a copy of the GNU Affero General Public License
* along with AjaXplorer.  If not, see <http://www.gnu.org/licenses/>.
*
* The latest code can be found at <http://www.ajaxplorer.info/>.
*/
$mess=array(
"Update Engine" => "Update Engine",
"Automatic update of AjaXplorer. Since version 3.3.3" => "Automatic update of AjaXplorer. Since version 3.3.3",
"Update Site" => "Update Site",
"Where to update" => "Where to update",
"Preserve Files" => "Preserve Files",
"Files declared here (enter pathes from the root of Ajxp installation, comma-separated) will be backed up and restored before and after upgrade." => "Files declared here (enter pathes from the root of Ajxp installation, comma-separated) will be backed up and restored before and after upgrade.",
"Enable Import From v3.2.4" => "Enable Import From v3.2.4",
"Enable the migration action, available in the Settings repository" => "Enable the migration action, available in the Settings repository",
"Update Channel" => "Update Channel",
"Check stable or dev channel" => "Check stable or dev channel",
);
?>

==> ajaxplorer-5.0.1.tbz: www/ajaxplorer/plugins/action.updater/i18n/conf/en.php <==
<?php
/*
* Copyright 2007-2011 Charles du Jeu <contact (at) cdujeu.me>
* This file is part of AjaXplorer.
*
* AjaXplorer is free software: you can redistribute it and/or modify
* it under the terms of the GNU Affero General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* AjaXplorer is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU Affero General Public License for more details.
*
* You should have received a copy of the GNU Affero General Public License
* along with AjaXplorer.  If not, see <http://www.gnu.org/licenses/>.
*
* The latest code can be found at <http://www.ajaxplorer.info/>.
*/
$mess=array(
"Update Engine" => "Update Engine",
"Automatic update of AjaXplorer. Since version 3.3.3" => "Automatic update of AjaXplorer. Since version 3.3.3",
"Update Site" => "Update Site",
"Where to update" => "Where to update",
"Preserve Files" => "Preserve Files",
"Files declared here (enter pathes from the root of Ajxp installation, comma-separated) will be backed up and restored before and after upgrade." => "Files declared here (enter pathes from the root of Ajxp installation, comma-separated) will be backed up and restored before and after upgrade.",
"Enable Import From v3.2.4" => "Enable Import From v3.2.4",
"Enable the migration action, available in the Settings repository" => "Enable the migration action, available in the Settings workspace",
"Update Channel" => "Update Channel",
"Check stable or dev channel" => "Check stable or dev channel",
);
?>
